# Changelog

## 📦 0.2.0

* Search for packages with a `[maintained|no]` badge in the README
* Add JSON output via `--format json`
* Improve code for normalizing minor variations of the same GitHub repo URL

## 📦 0.1.0

* First release
